## `gateway` Package

This `gateway` package contains all the classes that supports
the core functionality for concepts such as: 

- Gateway 
- Driver
- Communication/collaboration between Gateway and Drivers.

For details, each module in this package has _Docstrings_ 
that helps to describe its purpose. 
